@@ -11,9 +11,11 @@ from .helpers import get_domain
 @click.command()
 @click.argument("url")
 @click.option("-u", "--update", is_flag=True, help="Forces update of local database")
-@click.option("-l", "--limit", default=14, help="Shows visits & pageviews for the last XY days")
-@click.version_option("0.3.0")
-def cli(url: str, update: bool, limit: int) -> None:
+@click.option("-l", "--limit", default=14, help="Shows visits & pageviews for the last XY days. Default: 14")
+@click.option("-b", "--bar-colors", type=str, help="Defines two bar colors. Default: 'blue,magenta'")
+@click.option("-t", "--text-colors", type=str, help="Defines three text colors. Default: 'blue,white,cyan'")
+@click.version_option("0.4.0")
+def cli(url: str, update: bool, limit: int, bar_colors: str, text_colors: str) -> None:
     """
     Provides 'Goatcounter' statistics for URL
     """
@@ -21,11 +23,28 @@ def cli(url: str, update: bool, limit: int) -> None:
     # Determine base directory
     base_dir = click.get_app_dir("goatpie")
 
-    # Define minimum update interval (in seconds)
+    # Configure application
+    # (1) Set minimum update interval (in seconds)
     interval = 1 * 60 * 60  # 1 hour
 
+    # (2) Set steps used on Y-axis
+    step = 100
+
+    # (3) Set bar colors
+    bar_colors_default = "blue,magenta"
+
+    # (4) Set text colors
+    text_colors_default = "blue,white,cyan"
+
     # Initialize config object (using defaults)
-    config = configparser.ConfigParser(defaults={"interval": interval})
+    config = configparser.ConfigParser(
+        defaults={
+            "interval": interval,
+            "step": step,
+            "bar_colors": bar_colors_default,
+            "text_colors": text_colors_default,
+        }
+    )
 
     # Get path to config file
     config_file = os.path.join(base_dir, "config.ini")
@@ -47,6 +66,9 @@ def cli(url: str, update: bool, limit: int) -> None:
         # .. create it & add interval option
         config.add_section(domain)
         config.set(domain, "interval", str(interval))
+        config.set(domain, "step", str(step))
+        config.set(domain, "bar_colors", bar_colors_default)
+        config.set(domain, "text_colors", text_colors_default)
 
     # If no API token for domain section ..
     if not config.has_option(domain, "token"):
@@ -77,6 +99,19 @@ def cli(url: str, update: bool, limit: int) -> None:
     # Configure it
     app.obj = obj
     app.limit = limit
+    app.step = int(config[domain].get("step", step))
+
+    app.bar_colors = (
+        config[domain].get("bar_colors", bar_colors_default).split(",")
+        if bar_colors is None
+        else bar_colors.split(",")
+    )
+
+    app.text_colors = (
+        config[domain].get("text_colors", text_colors_default).split(",")
+        if text_colors is None
+        else text_colors.split(",")
+    )
 
     # Run!
     app.run(title='"Goatcounter" analytics', log=os.path.join(base_dir, "app.log"))
