@@ -1,5 +1,3 @@
-from typing import Optional
-
 from rich.padding import Padding
 from rich.panel import Panel
 from textual.widget import Widget
@@ -12,23 +10,26 @@ class GoatBar(Widget):
     Textual widget for 'multiple_bar' plot created with 'plotext'
     """
 
-    def __init__(self, obj, name: Optional[str] = None, limit: int = 14) -> None:
+    def __init__(self, obj, limit: int, step: int, bar_colors: list) -> None:
         """
         Initializes 'GoatBar' instance
 
         :param obj: goatpie.GoatPie
-        :param name: str
-        :param limit: int Limits data being displayed
+        :param limit: int Bar colors
+        :param step: int Limits data being displayed
+        :param bar_colors: list Steps used on Y-axis
 
         :return: None
         """
 
         # Initialize parent
-        super().__init__(name)
+        super().__init__("GoatBar")
 
         # Set plotter & settings
         self.obj = obj
         self.limit = limit
+        self.step = step
+        self.bar_colors = bar_colors
 
     def render(self) -> Panel:
         """
@@ -38,7 +39,7 @@ class GoatBar(Widget):
         """
 
         # Create 'rich' element
-        renderable = plotextRenderable(self.obj, self.limit)
+        renderable = plotextRenderable(self.obj, self.limit, self.step, self.bar_colors)
 
         # Define top padding
         spacing = (1, 0, 0, 0)
