@@ -9,10 +9,9 @@ from typing import Optional
 
 import arrow
 import pandas
-import pycountry
 import requests
 
-from .helpers import get_domain
+from .helpers import get_country, get_device, get_domain
 
 
 class GoatPie:
@@ -58,8 +57,19 @@ class GoatPie:
         # Create data directory (if needed)
         os.makedirs(data_dir, exist_ok=True)
 
-        # Initialize logger
-        self.logger = self.get_logger(data_dir)
+        # Initialize logger & set logging level
+        self.logger = logging.getLogger(__name__)
+        self.logger.setLevel(logging.DEBUG)
+
+        # Create log handler
+        handler = RotatingFileHandler(os.path.join(data_dir, "debug.log"), maxBytes=10000)
+
+        # Format logfile content
+        formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
+        handler.setFormatter(formatter)
+
+        # Add handler to logger
+        self.logger.addHandler(handler)
 
         # Connect to database
         db_file = os.path.join(data_dir, "db.sqlite")
@@ -464,7 +474,7 @@ class GoatPie:
         )
 
         # Replace screen size with device type
-        devices["Device"] = devices["Device"].map(self.get_device)
+        devices["Device"] = devices["Device"].map(get_device)
 
         # Group device types & aggregate their totals
         devices = devices.groupby("Device").agg({"Total": sum, "Device": "first"})
@@ -503,88 +513,9 @@ class GoatPie:
         countries["Country"] = countries["Country"].astype(str)
 
         # (2) Replace entries
-        countries["Country"] = countries["Country"].map(self.get_country)
+        countries["Country"] = countries["Country"].map(get_country)
 
         # Add percentages
         countries["%"] = round(countries["Total"] / countries["Total"].sum() * 100, 1)
 
         return countries.head(limit)
-
-    # Helper functions
-
-    def get_logger(self, log_dir: str) -> logging.Logger:
-        """
-        Initializes logger
-
-        :param log_dir: str Path to logfile
-
-        :return: logging.Logger
-        """
-
-        # Initialize logger & set logging level
-        logger = logging.getLogger(__name__)
-        logger.setLevel(logging.DEBUG)
-
-        # Create handler
-        handler = RotatingFileHandler(os.path.join(log_dir, "debug.log"), maxBytes=10000)
-
-        # Format logfile content
-        formatter = logging.Formatter("%(asctime)s - %(name)s - %(levelname)s - %(message)s")
-        handler.setFormatter(formatter)
-
-        # Add handler to logger
-        logger.addHandler(handler)
-
-        return logger
-
-    def get_device(self, size: str) -> str:
-        """
-        Converts screen size to device type (if applicable)
-
-        :param size: str Screen size (w,h,dpi)
-
-        :return: str Device type (if matched), otherwise 'unknown'
-        """
-
-        # Strip whitespaces
-        size = size.strip()
-
-        # If size undefined ..
-        if not size:
-            # .. assign zero ('unknown device')
-            size = 0
-
-        # Determine largest value (width OR height)
-        size = int(max(size.split(",")))
-
-        # Map screen size to device type
-        if size > 3000:
-            return "Computer monitors larger than HD"
-
-        if size > 1920:
-            return "Computer monitors"
-
-        if size > 1100:
-            return "Tablets and small laptops"
-
-        if size > 1000:
-            return "Large phones, small tablets"
-
-        if size > 300:
-            return "Phones"
-
-        return "Unknown devices"
-
-    def get_country(self, code: str) -> str:
-        """
-        Converts country code to country name (if applicable)
-
-        :param code: str Country code
-
-        :return: str Country name (if successful), otherwise country code
-        """
-
-        # Look up country code
-        country = pycountry.countries.get(alpha_2=code)
-
-        return code if country is None else country.name
