@@ -2,7 +2,7 @@ import urllib
 from typing import Optional
 
 import pandas
-import plotext
+import pycountry
 from rich import box
 from rich.table import Column, Table
 
@@ -39,81 +39,74 @@ def get_domain(url: str, keep_subdomain: bool = False) -> str:
     return netloc
 
 
-def render_stats(
-    obj,
-    width: int,
-    height: int,
-    labels: Optional[list] = None,
-    colors: Optional[list] = None,
-    limit: int = 14,
-    step: int = 100,
-) -> str:
+def get_device(size: str) -> str:
     """
-    Renders visits & pageviews using 'plotext'
+    Converts screen size to device type (if applicable)
 
-    :param obj: goatpie.GoatPie
-    :param width: int Plot width
-    :param height: int Plot height
-    :param labels: list Data labels
-    :param colors: list Bar colors
-    :param limit: int Limits data to last XY days
-    :param step: int Steps used on Y-axis
+    :param size: str Screen size (w,h,dpi)
 
-    :return: str Plotted canvas
+    :return: str Device type (if matched), otherwise 'unknown'
     """
 
-    # If not specified ..
-    # (1) .. assign default labels
-    if labels is None:
-        labels = ["Visits", "Pageviews"]
+    # Remove whitespaces
+    size = "".join(size.split())
 
-    # (2) .. assign default colors
-    if colors is None:
-        colors = ["blue", "magenta"]
+    try:
+        # Determine largest value (width OR height)
+        size = int(max(map(int, size.split(","))))
 
-    # Clear everything
-    plotext.clf()
-    plotext.clc()
+    except ValueError:
+        # .. report back
+        return "Unknown devices"
 
-    # Retrieve data
-    visits = obj.get_visits(limit)
-    pageviews = obj.get_pageviews(limit)
+    # Map screen size to device type
+    if size >= 3000:
+        return "Computer monitors larger than HD"
 
-    # Determine relative bar width
-    # FIX: Actually calculate something
-    bar_width = 0.4
+    if size >= 1920:
+        return "Computer monitors"
 
-    # Configure plot
-    plotext.multiple_bar(
-        visits.Day, [visits.Visits, pageviews.Pageviews], label=labels, width=bar_width, marker="hd", color=colors
-    )
-    plotext.plotsize(width, height)
-    plotext.xlabel("hits / day")
-    plotext.frame(False)
-    plotext.ticks_color("white")
-    plotext.ticks_style("bold")
-    plotext.xticks([])
-    plotext.yticks(range(0, pageviews.Pageviews.max(), step))
+    if size >= 1100:
+        return "Tablets and small laptops"
 
-    return plotext.build()
+    if size >= 1000:
+        return "Large phones, small tablets"
+
+    if size >= 300:
+        return "Phones"
+
+    return "Unknown devices"
 
 
-def data2table(data: pandas.DataFrame, title: Optional[str] = None, colors: Optional[list] = None) -> Table:
+def get_country(code: str) -> str:
+    """
+    Converts country code to country name (if applicable)
+
+    :param code: str Country code
+
+    :return: str Country name (if successful), otherwise country code
+    """
+
+    # Strip surrounding whitespaces
+    code = code.strip()
+
+    # Look up country code
+    country = pycountry.countries.get(alpha_2=code)
+
+    return code if country is None else country.name
+
+
+def data2table(data: pandas.DataFrame, colors: list, title: Optional[str] = None) -> Table:
     """
     Creates 'rich' table from 'pandas' dataframe
 
     :param data: pandas.DataFrame Table data
-    :param title: str Table heading
     :param colors: list Column text colors
+    :param title: str Table heading
 
     :return: rich.table.Table
     """
 
-    # If not specified ..
-    if colors is None:
-        # .. assign defaults
-        colors = ["blue", "white", "cyan"]
-
     # Create header row
     header = [Column(header=header, justify="right", style=colors[idx]) for idx, header in enumerate(data.columns)]
 
